==> IMSTransport-1.0.3-final.tar.gz: IMSTransport/tool/IMSTransportTool.py <==
##################################################################################
#
#    Copyright (C) 2004-2006 Utah State University, All rights reserved.
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
##################################################################################

__author__ = '''Brent Lambert, David Ray, Jon Thomas'''
__docformat__ = 'plaintext'
__version__ = "$Revision: 2618 $"[11:-2]


from OFS.SimpleItem import SimpleItem
from Products.CMFCore.utils import UniqueObject
from OFS.PropertyManager import PropertyManager
from Globals import InitializeClass
from AccessControl import ClassSecurityInfo
from Products.Archetypes.atapi import *
from Products.CMFCore import permissions
from Products.PageTemplates.PageTemplateFile import PageTemplateFile
from StructuredText.StructuredText import HTML
from Products.IMSTransport.config import *
from Products.IMSTransport.interfaces import IIMSManifestWriter, IIMSManifestReader
from Products.IMSTransport.Manifest import ZipfileReader, ZipfileWriter
from zipfile import BadZipfile
                
class IMSTransportTool(UniqueObject, SimpleItem, PropertyManager):
    """
    A tool to move courses and metadata in and out of Plone using IMS content packaging.
    """
    security = ClassSecurityInfo()
    
    id = 'portal_IMSTransportTool'
    meta_type = 'IMSTransportTool'
    title = 'IMS Transport Tool'
    plone_tool = True
    toolicon = 'tool.gif'

    __implements__ = (getattr(UniqueObject,'__implements__',()),) + \
                     (getattr(SimpleItem,'__implements__',()),)

    _properties = PropertyManager._properties + (
        {'id':'import_xforms', 'type':'lines', 'mode':'w'},
        {'id':'export_xforms', 'type':'lines', 'mode':'w'},
        #{'id':'mitdspace_import_xform', 'type':'lines', 'mode':'w'},
        #{'id':'angel_import_xform', 'type':'lines', 'mode':'w'},
        #{'id':'eXe_import_xform', 'type':'lines', 'mode':'w'},
        {'id':'WebCT_import_xform', 'type':'lines', 'mode':'w'},
        {'id':'Blackboard_import_xform', 'type':'lines', 'mode':'w'},
    )

    import_xforms = [#'mitdspace_import_xform',
                     #'angel_import_xform',
                     #'eXe_import_xform',
                     'WebCT_import_xform',
                     'Blackboard_import_xform',]
    
    export_xforms = []

    #mitdspace_import_xform = ['MIT/DSpace', 'MITDspace_import_xform.xsl']
    #angel_import_xform = ['Angel', 'Angel_import_xform.xsl']
    #eXe_import_xform = ['eXe', 'eXe_import_xform.xsl']
    WebCT_import_xform = ['WebCT CE 6.0', 'WebCT_import_xform.xsl']
    Blackboard_import_xform = ['Blackboard 6.1/7.0', 'Blackboard_import_xform.xsl']
    Blackboard_content_import_transform = ['Blackboard Content', 'Blackboard_content_import_xform.xsl']
    WebCT_image_xform = ['WebCT Images', 'WebCT_image_xform.xsl']
    WebCT_glossary_xform = ['WebCT Glossary', 'WebCT_glossary_xform.xsl']
    
    manage_options = (({'label' : 'Overview', 'action' : 'manage_overview'},) +
                      PropertyManager.manage_options +
                      ({'label' : 'Import/Export Content', 'action' : 'manage_IMSTransport'},))


    security.declareProtected(permissions.ManagePortal, 'manage_overview')
    manage_overview = PageTemplateFile('overview', WWW_DIR)

    security.declareProtected(permissions.ManagePortal, 'manage_IMSTransport')
    manage_IMSTransport = PageTemplateFile('IMS_transport_form', WWW_DIR)


    tocpage = PageTemplateFile('tableofcontents', WWW_DIR)


    security.declareProtected(permissions.ModifyPortalContent, 'importZipfile')
    def importZipfile(self, object, file, package_type, mdVersions=None, rtype='IMSTransport'):
        """ Import a zip file. """

        reader = IIMSManifestReader(object)
        reader.setReaderType(rtype)
        try:
            zfr = ZipfileReader(file)
        except BadZipfile, e:
            return False, 'Zip', e
        reader.setSource(zfr)
        if mdVersions:
            reader.setRequiredMetadataSections(mdVersions)
        pt = getattr(self, package_type, None)
        return reader.readManifest(pt)

    security.declareProtected(permissions.ModifyPortalContent, 'exportZipfile')
    def exportZipfile(self, object, filename, wtype='IMSTransport'):
        """ Export a zip file. """
        writer = IIMSManifestWriter(object)
        writer.setWriterType(wtype)
        writer.setDestination(ZipfileWriter(filename, object.getId()))
        return writer.writeManifest()

InitializeClass(IMSTransportTool)

==> IMSTransport-1.0.4-final.tar.gz: IMSTransport/tool/IMSTransportTool.py <==
##################################################################################
#
#    Copyright (C) 2004-2006 Utah State University, All rights reserved.
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
##################################################################################

__author__ = '''Brent Lambert, David Ray, Jon Thomas'''
__docformat__ = 'plaintext'
__version__ = "$Revision: 2618 $"[11:-2]


from OFS.SimpleItem import SimpleItem
from Products.CMFCore.utils import UniqueObject
from OFS.PropertyManager import PropertyManager
from Globals import InitializeClass
from AccessControl import ClassSecurityInfo
from Products.Archetypes.atapi import *
from Products.CMFCore import permissions
from Products.PageTemplates.PageTemplateFile import PageTemplateFile
from StructuredText.StructuredText import HTML
from Products.IMSTransport.config import *
from Products.IMSTransport.interfaces import IIMSManifestWriter, IIMSManifestReader
from Products.IMSTransport.Manifest import ZipfileReader, ZipfileWriter
from zipfile import BadZipfile
                
class IMSTransportTool(UniqueObject, SimpleItem, PropertyManager):
    """
    A tool to move courses and metadata in and out of Plone using IMS content packaging.
    """
    security = ClassSecurityInfo()
    
    id = 'portal_IMSTransportTool'
    meta_type = 'IMSTransportTool'
    title = 'IMS Transport Tool'
    plone_tool = True
    toolicon = 'tool.gif'

    __implements__ = (getattr(UniqueObject,'__implements__',()),) + \
                     (getattr(SimpleItem,'__implements__',()),)

    _properties = PropertyManager._properties + (
        {'id':'import_xforms', 'type':'lines', 'mode':'w'},
        {'id':'export_xforms', 'type':'lines', 'mode':'w'},
        {'id':'mitdspace_import_xform', 'type':'lines', 'mode':'w'},
        #{'id':'angel_import_xform', 'type':'lines', 'mode':'w'},
        #{'id':'eXe_import_xform', 'type':'lines', 'mode':'w'},
        {'id':'WebCT_import_xform', 'type':'lines', 'mode':'w'},
        {'id':'Blackboard_import_xform', 'type':'lines', 'mode':'w'},
    )

    import_xforms = ['mitdspace_import_xform',
                     #'angel_import_xform',
                     #'eXe_import_xform',
                     'WebCT_import_xform',
                     'Blackboard_import_xform',]
    
    export_xforms = []

    mitdspace_import_xform = ['MIT OCW', 'MITDspace_import_xform.xsl']
    #angel_import_xform = ['Angel', 'Angel_import_xform.xsl']
    #eXe_import_xform = ['eXe', 'eXe_import_xform.xsl']
    WebCT_import_xform = ['WebCT CE 6.0', 'WebCT_import_xform.xsl']
    Blackboard_import_xform = ['Blackboard 6.1/7.0', 'Blackboard_import_xform.xsl']
    Blackboard_content_import_transform = ['Blackboard Content', 'Blackboard_content_import_xform.xsl']
    WebCT_image_xform = ['WebCT Images', 'WebCT_image_xform.xsl']
    WebCT_glossary_xform = ['WebCT Glossary', 'WebCT_glossary_xform.xsl']
    
    manage_options = (({'label' : 'Overview', 'action' : 'manage_overview'},) +
                      PropertyManager.manage_options +
                      ({'label' : 'Import/Export Content', 'action' : 'manage_IMSTransport'},))


    security.declareProtected(permissions.ManagePortal, 'manage_overview')
    manage_overview = PageTemplateFile('overview', WWW_DIR)

    security.declareProtected(permissions.ManagePortal, 'manage_IMSTransport')
    manage_IMSTransport = PageTemplateFile('IMS_transport_form', WWW_DIR)


    tocpage = PageTemplateFile('tableofcontents', WWW_DIR)


    security.declareProtected(permissions.ModifyPortalContent, 'importZipfile')
    def importZipfile(self, object, file, package_type, mdVersions=None, rtype='IMSTransport'):
        """ Import a zip file. """

        reader = IIMSManifestReader(object)
        reader.setReaderType(rtype)
        try:
            zfr = ZipfileReader(file)
        except BadZipfile, e:
            return False, 'Zip', e
        reader.setSource(zfr)
        if mdVersions:
            reader.setRequiredMetadataSections(mdVersions)
        pt = getattr(self, package_type, None)
        return reader.readManifest(pt)

    security.declareProtected(permissions.ModifyPortalContent, 'exportZipfile')
    def exportZipfile(self, object, filename, wtype='IMSTransport'):
        """ Export a zip file. """
        writer = IIMSManifestWriter(object)
        writer.setWriterType(wtype)
        writer.setDestination(ZipfileWriter(filename, object.getId()))
        return writer.writeManifest()

InitializeClass(IMSTransportTool)
